# Copyright 2001-2004 Six Apart. This code cannot be redistributed without
# permission from www.movabletype.org.
#
# $Id: AuthorBanList.pm,v 1.8 2004/08/25 02:06:40 ezra Exp $

package MT::AuthorBanList;
use strict;

use MT::Object;
@MT::AuthorBanList::ISA = qw( MT::Object );
__PACKAGE__->install_properties({
    columns => [
        'id', 'blog_id', 'author',
    ],
    indexes => {
        blog_id => 1,
        author => 1,
    },
    audit => 1,
    datasource => 'AuthorBanList',
    primary_key => 'id',
});

sub ban_ip {
    my $class = shift;
    my ($author, $blog_id) = @_;
    my $record = $class->load({author => $author});
    return 1 if (defined($record) && UNIVERSAL::isa($record, 'MT::AuthorBanList')
                 && $record->author eq $author);

    $record = $class->new();
    $record->author($author);
    $record->blog_id($blog_id);
    return $record->save();
}


1;
__END__

=head1 NAME

MT::AuthorBanList - Movable Type IP comment banning record

=head1 SYNOPSIS

    use MT::AuthorBanList;
    my $ban = MT::AuthorBanList->new;
    $ban->blog_id($blog->id);
    $ban->author($author);
    $ban->save
        or die $ban->errstr;

=head1 DESCRIPTION

An I<MT::AuthorBanList> object represents a single author name that is banned from
commenting on one of your blogs.

=head1 USAGE

As a subclass of I<MT::Object>, I<MT::AuthorBanList> inherits all of the
data-management and -storage methods from that class; thus you should look
at the I<MT::Object> documentation for details about creating a new object,
loading an existing object, saving an object, etc.

=head1 DATA ACCESS METHODS

The I<MT::AuthorBanList> object holds the following pieces of data. These fields can
be accessed and set using the standard data access methods described in the
I<MT::Object> documentation.

=over 4

=item * id

The numeric ID of the banlist record.

=item * blog_id

The numeric ID of the blog for which the IP address is banned.

=item * author

The author name. This can be a partial author name--for example, a partial
name of C<what> will block the IP addresses C<whatever>,
C<whatchamacallit>, etc.

=back

=head1 DATA LOOKUP

In addition to numeric ID lookup, you can look up or sort records by any
combination of the following fields. See the I<load> documentation in
I<MT::Object> for more information.

=over 4

=item * blog_id

=item * author

=back

=head1 AUTHOR & COPYRIGHTS

Please see the I<MT> manpage for author, copyright, and license information.

=cut
